pycocoa.geometry

Package pycocoa :: Module geometry |
[frames] | no frames]

# Module geometry

Types Point, Rect and Size, wrapping ObjC `NSPoint_t`, NSRect_t, `NSSize_t`.

Version: 25.02.16

Classes
| Point Python Type, wrapping an ObjC `NSPoint_t`.
| Point2 Python Type, like Point, different signature.
| Rect Python Type, wrapping an ObjC NSRect_t.
| Rect4 Python Type, like Rect, but signature as ObjC NSRect4_t.
| Size Python Type, wrapping an ObjC `NSSize_t`.
| Size2 Python Type, like Size, different signature.

Variables
| __all__ = `_ALL_LAZY.geometry`